pub enum ExcelError {
Io(Error),
Zip(ZipError),
TooManySheets,
RowLimitExceeded,
ColumnLimitExceeded,
HeaderAfterRows,
SheetAlreadyExists,
}Variants
Io(Error)
An IO error occurred while writing to an underlying writer.
Zip(ZipError)
An error occurred zipping the excel file.
TooManySheets
Attempted to create more sheets than the maximum allowed (65535).
RowLimitExceeded
Attempted to write more rows than Excel supports (1048576).
ColumnLimitExceeded
Attempted to write more columns than Excel supports (16384).
HeaderAfterRows
Attempted to write header after already writing rows.
SheetAlreadyExists
Attempted to create a sheet that already exists.