WorkBook

Struct WorkBook 

pub struct WorkBook<W: Write + Seek> { /* private fields */ }
A WorkBook represents one excel file.

Implementations

Source

impl<W: Write + Seek> WorkBook<W>

pub fn new(writer: W) -> Self

Create a new WorkBook. writer is the destination to write the excel file to

pub fn new_worksheet<'a>(&'a mut self, name: String) -> Result<Sheet<'a, W>>

Creates a new Sheet with the given name.

pub fn finish(self) -> Result<W>

Finish writing to the excel file. This closes the file and wraps up any remaining operations.